@@ -23,10 +23,11 @@ BaseHistory::BaseHistory() : mTrackedURIs(kTrackedUrisInitialSize) {}
 BaseHistory::~BaseHistory() = default;
 
 static constexpr nsLiteralCString kDisallowedSchemes[] = {
-    "about"_ns,         "blob"_ns,       "data"_ns,     "chrome"_ns,
-    "imap"_ns,          "javascript"_ns, "mailbox"_ns,  "moz-anno"_ns,
-    "news"_ns,          "page-icon"_ns,  "resource"_ns, "view-source"_ns,
-    "moz-extension"_ns,
+    "about"_ns,         "blob"_ns,           "cached-favicon"_ns,
+    "chrome"_ns,        "data"_ns,           "imap"_ns,
+    "javascript"_ns,    "mailbox"_ns,        "news"_ns,
+    "page-icon"_ns,     "resource"_ns,       "view-source"_ns,
+    "moz-extension"_ns, "moz-page-thumb"_ns,
 };
 
 bool BaseHistory::CanStore(nsIURI* aURI) {
@@ -93,8 +94,15 @@ void BaseHistory::RegisterVisitedCallback(nsIURI* aURI, Link* aLink) {
       mTrackedURIs.WithEntryHandle(aURI, [&](auto&& entry) -> ObservingLinks* {
         MOZ_DIAGNOSTIC_ASSERT(!entry || !entry->mLinks.IsEmpty(),
                               "An empty key was kept around in our hashtable!");
+
         if (!entry) {
-          ScheduleVisitedQuery(aURI, nullptr);
+          // If the URI has userpass, skip the visit query scheduling, because
+          // these URIs are not stored by history, and their status is only
+          // updated at the time of a visit.
+          bool hasUserPass;
+          if (NS_FAILED(aURI->GetHasUserPass(&hasUserPass)) || !hasUserPass) {
+            ScheduleVisitedQuery(aURI, nullptr);
+          }
         }
 
         return &entry.OrInsertWith([] { return ObservingLinks{}; });
@@ -116,9 +124,6 @@ void BaseHistory::RegisterVisitedCallback(nsIURI* aURI, Link* aLink) {
     case VisitedStatus::Unknown:
       break;
     case VisitedStatus::Unvisited:
-      if (!StaticPrefs::layout_css_notify_of_unvisited()) {
-        break;
-      }
       [[fallthrough]];
     case VisitedStatus::Visited:
       aLink->VisitedQueryFinished(links->mStatus == VisitedStatus::Visited);
@@ -159,11 +164,6 @@ void BaseHistory::NotifyVisited(
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_ASSERT(aStatus != VisitedStatus::Unknown);
 
-  if (aStatus == VisitedStatus::Unvisited &&
-      !StaticPrefs::layout_css_notify_of_unvisited()) {
-    return;
-  }
-
   NotifyVisitedInThisProcess(aURI, aStatus);
   if (XRE_IsParentProcess()) {
     NotifyVisitedFromParent(aURI, aStatus, aListOfProcessesToNotify);
@@ -216,7 +216,9 @@ void BaseHistory::SendPendingVisitedResultsToChildProcesses() {
         resultsForProcess.AppendElement(result.mResult);
       }
     }
-    Unused << NS_WARN_IF(!cp->SendNotifyVisited(resultsForProcess));
+    if (!resultsForProcess.IsEmpty()) {
+      Unused << NS_WARN_IF(!cp->SendNotifyVisited(resultsForProcess));
+    }
   }
 }
 
