@@ -8,7 +8,6 @@
 
 ChromeUtils.defineESModuleGetters(this, {
   GeckoViewTabBridge: "resource://gre/modules/GeckoViewTab.sys.mjs",
-  PromiseUtils: "resource://gre/modules/PromiseUtils.sys.mjs",
   mobileWindowTracker: "resource://gre/modules/GeckoViewWebExtension.sys.mjs",
 });
 
@@ -29,7 +28,7 @@ const tabListener = {
     }
   },
 
-  onLocationChange(browser, webProgress, request, locationURI, flags) {
+  onLocationChange(browser, webProgress, request) {
     if (webProgress.isTopLevel) {
       const { tab } = browser.ownerGlobal;
 
@@ -62,7 +61,7 @@ const tabListener = {
   awaitTabReady(nativeTab) {
     let deferred = this.tabReadyPromises.get(nativeTab);
     if (!deferred) {
-      deferred = PromiseUtils.defer();
+      deferred = Promise.withResolvers();
       if (
         !this.initializingTabs.has(nativeTab) &&
         (nativeTab.browser.innerWindowID ||
@@ -104,7 +103,7 @@ this.tabs = class extends ExtensionAPIPersistent {
   }
 
   PERSISTENT_EVENTS = {
-    onActivated({ fire, context }, params) {
+    onActivated({ fire, context }) {
       const listener = (eventName, event) => {
         const { windowId, tabId, isPrivate } = event;
         if (isPrivate && !context.privateBrowsingAllowed) {
@@ -141,7 +140,7 @@ this.tabs = class extends ExtensionAPIPersistent {
         });
       },
     }),
-    onUpdated({ fire, context }, params) {
+    onUpdated({ fire }) {
       const { tabManager } = this.extension;
       const restricted = ["url", "favIconUrl", "title"];
 
@@ -221,9 +220,8 @@ this.tabs = class extends ExtensionAPIPersistent {
           windowTracker.removeListener("status", statusListener);
           windowTracker.removeListener("pagetitlechanged", listener);
         },
-        convert(_fire, _context) {
+        convert(_fire) {
           fire = _fire;
-          context = _context;
         },
       };
     },
@@ -330,7 +328,7 @@ this.tabs = class extends ExtensionAPIPersistent {
         onAttached: new EventManager({
           context,
           name: "tabs.onAttached",
-          register: fire => {
+          register: () => {
             return () => {};
           },
         }).api(),
@@ -338,7 +336,7 @@ this.tabs = class extends ExtensionAPIPersistent {
         onDetached: new EventManager({
           context,
           name: "tabs.onDetached",
-          register: fire => {
+          register: () => {
             return () => {};
           },
         }).api(),
@@ -353,7 +351,7 @@ this.tabs = class extends ExtensionAPIPersistent {
         onReplaced: new EventManager({
           context,
           name: "tabs.onReplaced",
-          register: fire => {
+          register: () => {
             return () => {};
           },
         }).api(),
@@ -361,7 +359,7 @@ this.tabs = class extends ExtensionAPIPersistent {
         onMoved: new EventManager({
           context,
           name: "tabs.onMoved",
-          register: fire => {
+          register: () => {
             return () => {};
           },
         }).api(),
@@ -380,7 +378,6 @@ this.tabs = class extends ExtensionAPIPersistent {
           index,
           openInReaderMode,
           pinned,
-          title,
           url,
         } = {}) {
           if (active === null) {
@@ -544,13 +541,25 @@ this.tabs = class extends ExtensionAPIPersistent {
               ? windowTracker.topWindow
               : windowTracker.getWindow(windowId, context);
 
-          const tab = tabManager.wrapTab(window.tab);
+          const tab = tabManager.getWrapper(window.tab);
+          if (
+            !extension.hasPermission("<all_urls>") &&
+            !tab.hasActiveTabPermission
+          ) {
+            throw new ExtensionError("Missing activeTab permission");
+          }
           await tabListener.awaitTabReady(tab.nativeTab);
           const zoom = window.browsingContext.fullZoom;
 
           return tab.capture(context, zoom, options);
         },
 
+        async detectLanguage(tabId) {
+          const tab = await promiseTabWhenReady(tabId);
+          const results = await tab.queryContent("DetectLanguage", {});
+          return results[0];
+        },
+
         async executeScript(tabId, details) {
           const tab = await promiseTabWhenReady(tabId);
 
