@@ -26,6 +26,9 @@ const APIS = {
   GetPidForTab({ tab }) {
     return browser.test.getPidForTab(tab.id);
   },
+  WaitForContentTransformsReceived({ tab }) {
+    return browser.test.waitForContentTransformsReceived(tab.id);
+  },
   GetProfilePath() {
     return browser.test.getProfilePath();
   },
@@ -77,6 +80,12 @@ const APIS = {
   TriggerCookieBannerHandled({ tab }) {
     return browser.test.triggerCookieBannerHandled(tab.id);
   },
+  TriggerTranslationsOffer({ tab }) {
+    return browser.test.triggerTranslationsOffer(tab.id);
+  },
+  TriggerLanguageStateChange({ tab, languageState }) {
+    return browser.test.triggerLanguageStateChange(tab.id, languageState);
+  },
 };
 
 port.onMessage.addListener(async message => {
