@@ -7,16 +7,27 @@ package org.mozilla.gecko;
 import android.content.ClipData;
 import android.content.ClipDescription;
 import android.content.ClipboardManager;
+import android.content.ClipboardManager.OnPrimaryClipChangedListener;
 import android.content.Context;
+import android.content.res.AssetFileDescriptor;
 import android.os.Build;
 import android.text.TextUtils;
 import android.util.Log;
+import java.io.ByteArrayOutputStream;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.util.concurrent.atomic.AtomicLong;
 import org.mozilla.gecko.annotation.WrapForJNI;
 
 public final class Clipboard {
   private static final String HTML_MIME = "text/html";
   private static final String PLAINTEXT_MIME = "text/plain";
   private static final String LOGTAG = "GeckoClipboard";
+  private static final int DEFAULT_BUFFER_SIZE = 8192;
+
+  private static OnPrimaryClipChangedListener sClipboardChangedListener = null;
+  private static final AtomicLong sClipboardSequenceNumber = new AtomicLong();
 
   private Clipboard() {}
 
@@ -27,11 +38,11 @@ public final class Clipboard {
    * @return a plain text string of clipboard data.
    */
   public static String getText(final Context context) {
-    return getData(context, PLAINTEXT_MIME);
+    return getTextData(context, PLAINTEXT_MIME);
   }
 
   /**
-   * Get the data on the primary clip on clipboard
+   * Get the text data on the primary clip on clipboard
    *
    * @param context application context
    * @param mimeType the mime type we want. This supports text/html and text/plain only. If other
@@ -39,7 +50,7 @@ public final class Clipboard {
    * @return a string into clipboard.
    */
   @WrapForJNI(calledFrom = "gecko")
-  public static String getData(final Context context, final String mimeType) {
+  private static String getTextData(final Context context, final String mimeType) {
     final ClipboardManager cm =
         (ClipboardManager) context.getSystemService(Context.CLIPBOARD_SERVICE);
     if (cm.hasPrimaryClip()) {
@@ -68,6 +79,52 @@ public final class Clipboard {
     return null;
   }
 
+  /**
+   * Get the blob data on the primary clip on clipboard
+   *
+   * @param mimeType the mime type we want.
+   * @return a byte array into clipboard.
+   */
+  @WrapForJNI(calledFrom = "gecko", exceptionMode = "nsresult")
+  private static byte[] getRawData(final String mimeType) {
+    final Context context = GeckoAppShell.getApplicationContext();
+    final ClipboardManager cm =
+        (ClipboardManager) context.getSystemService(Context.CLIPBOARD_SERVICE);
+    if (cm.hasPrimaryClip()) {
+      final ClipData clip = cm.getPrimaryClip();
+      if (clip == null || clip.getItemCount() == 0) {
+        return null;
+      }
+
+      final ClipDescription description = clip.getDescription();
+      if (description.hasMimeType(mimeType)) {
+        return getRawDataFromClipData(context, clip);
+      }
+    }
+    return null;
+  }
+
+  private static byte[] getRawDataFromClipData(final Context context, final ClipData clipData) {
+    try (final AssetFileDescriptor descriptor =
+            context
+                .getContentResolver()
+                .openAssetFileDescriptor(clipData.getItemAt(0).getUri(), "r");
+        final InputStream inputStream = new FileInputStream(descriptor.getFileDescriptor());
+        final ByteArrayOutputStream outputStream = new ByteArrayOutputStream()) {
+      final byte[] data = new byte[DEFAULT_BUFFER_SIZE];
+      int readed;
+      while ((readed = inputStream.read(data)) != -1) {
+        outputStream.write(data, 0, readed);
+      }
+      return outputStream.toByteArray();
+    } catch (final IOException e) {
+      Log.e(LOGTAG, "Couldn't get clip data from clipboard due to I/O error", e);
+    } catch (final OutOfMemoryError e) {
+      Log.e(LOGTAG, "Couldn't get clip data from clipboard due to OOM", e);
+    }
+    return null;
+  }
+
   /**
    * Set plain text to clipboard
    *
@@ -89,7 +146,7 @@ public final class Clipboard {
    * @return true if copy is successful.
    */
   @WrapForJNI(calledFrom = "gecko")
-  public static boolean setHTML(
+  private static boolean setHTML(
       final Context context, final CharSequence text, final String htmlText) {
     return setData(context, ClipData.newHtmlText("html", text, htmlText));
   }
@@ -128,12 +185,11 @@ public final class Clipboard {
    * @return true if the clipboard is nonempty, false otherwise.
    */
   @WrapForJNI(calledFrom = "gecko")
-  public static boolean hasData(final Context context, final String mimeType) {
+  private static boolean hasData(final Context context, final String mimeType) {
     if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.P) {
       if (HTML_MIME.equals(mimeType) || PLAINTEXT_MIME.equals(mimeType)) {
-        return !TextUtils.isEmpty(getData(context, mimeType));
+        return !TextUtils.isEmpty(getTextData(context, mimeType));
       }
-      return false;
     }
 
     // Calling getPrimaryClip causes a toast message from Android 12.
@@ -161,12 +217,16 @@ public final class Clipboard {
           || description.hasMimeType(ClipDescription.MIMETYPE_TEXT_PLAIN);
     }
 
-    return false;
+    return description.hasMimeType(mimeType);
   }
 
-  /** Deletes all text from the clipboard. */
+  /**
+   * Deletes all data from the clipboard.
+   *
+   * @param context application context
+   */
   @WrapForJNI(calledFrom = "gecko")
-  public static void clearText(final Context context) {
+  private static void clear(final Context context) {
     if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.P) {
       setText(context, null);
       return;
@@ -178,4 +238,47 @@ public final class Clipboard {
         (ClipboardManager) context.getSystemService(Context.CLIPBOARD_SERVICE);
     cm.clearPrimaryClip();
   }
+
+  /**
+   * Start monitor clipboard sequence number.
+   *
+   * @param context application context
+   */
+  @WrapForJNI(calledFrom = "gecko")
+  private static void startTrackingClipboardData(final Context context) {
+    if (sClipboardChangedListener != null) {
+      return;
+    }
+
+    sClipboardChangedListener =
+        new OnPrimaryClipChangedListener() {
+          @Override
+          public void onPrimaryClipChanged() {
+            Clipboard.sClipboardSequenceNumber.incrementAndGet();
+          }
+        };
+
+    final ClipboardManager cm =
+        (ClipboardManager) context.getSystemService(Context.CLIPBOARD_SERVICE);
+    cm.addPrimaryClipChangedListener(sClipboardChangedListener);
+  }
+
+  /** Stop monitor clipboard sequence number. */
+  @WrapForJNI(calledFrom = "gecko")
+  private static void stopTrackingClipboardData(final Context context) {
+    if (sClipboardChangedListener == null) {
+      return;
+    }
+
+    final ClipboardManager cm =
+        (ClipboardManager) context.getSystemService(Context.CLIPBOARD_SERVICE);
+    cm.removePrimaryClipChangedListener(sClipboardChangedListener);
+    sClipboardChangedListener = null;
+  }
+
+  /** Get clipboard sequence number. */
+  @WrapForJNI(calledFrom = "gecko")
+  private static long getSequenceNumber(final Context context) {
+    return sClipboardSequenceNumber.get();
+  }
 }
