@@ -896,10 +896,10 @@ final class BasicGeckoViewPrompt implements GeckoSession.PromptDelegate {
         (mimeType != null ? mimeType : "*") + '/' + (mimeSubtype != null ? mimeSubtype : "*"));
     intent.addCategory(Intent.CATEGORY_OPENABLE);
     intent.putExtra(Intent.EXTRA_LOCAL_ONLY, true);
-    if (Build.VERSION.SDK_INT >= 18 && prompt.type == FilePrompt.Type.MULTIPLE) {
+    if (prompt.type == FilePrompt.Type.MULTIPLE) {
       intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true);
     }
-    if (Build.VERSION.SDK_INT >= 19 && prompt.mimeTypes.length > 0) {
+    if (prompt.mimeTypes.length > 0) {
       intent.putExtra(Intent.EXTRA_MIME_TYPES, prompt.mimeTypes);
     }
 
